BarrierOperation

Struct BarrierOperation 

pub struct BarrierOperation<'c> { /* private fields */ }
A barrier operation. Synchronizes all work items of a workgroup..

The barrier op synchronizes all work items of a workgroup. It is used to coordinate communication between the work items of the workgroup.

gpu.barrier

waits until all work items in the workgroup have reached this point and all memory accesses made by these work items prior to the op are visible to all work items in the workgroup. Data hazards between work items accessing the same memory can be avoided by synchronizing work items in-between these accesses.

Either none or all work items of a workgroup need to execute this op in convergence.

Implementations

Source

impl<'c> BarrierOperation<'c>

pub fn name() -> &'static str

Returns a name.

pub fn as_operation(&self) -> &Operation<'c>

Returns a generic operation.

pub fn builder( context: &'c Context, location: Location<'c>, ) -> BarrierOperationBuilder<'c>

Creates a builder.