DestroyDnTensorOperation

Struct DestroyDnTensorOperation 

pub struct DestroyDnTensorOperation<'c> { /* private fields */ }
A destroy_dn_tensor operation. Destroy dense tensor operation.

The gpu.destroy_dn_tensor operation releases all resources of a dense tensor represented by a handle that was previously created by a gpu.create_dn_tensor operation.

If the async keyword is present, the op is executed asynchronously (i.e. it does not block until the execution has finished on the device). In that case, it returns a !gpu.async.token in addition to the environment.

Example:

%token = gpu.destroy_dn_tensor async [%dep] %dnTensor

Implementations

Source

impl<'c> DestroyDnTensorOperation<'c>

pub fn name() -> &'static str

Returns a name.

pub fn as_operation(&self) -> &Operation<'c>

Returns a generic operation.

pub fn builder( context: &'c Context, location: Location<'c>, ) -> DestroyDnTensorOperationBuilder<'c, Unset, Unset>

Creates a builder.

pub fn async_token(&self) -> Result<OperationResult<'c, '_>, Error>

pub fn async_dependencies(&self) -> impl Iterator<Item = Value<'c, '_>>

pub fn dn_tensor(&self) -> Result<Value<'c, '_>, Error>