pub struct BarrierOperation<'c> { /* private fields */ }Expand description
A barrier operation. Synchronizes all work items of a workgroup..
The barrier op synchronizes all work items of a workgroup. It is used
to coordinate communication between the work items of the workgroup.
gpu.barrierwaits until all work items in the workgroup have reached this point and all memory accesses made by these work items prior to the op are visible to all work items in the workgroup. Data hazards between work items accessing the same memory can be avoided by synchronizing work items in-between these accesses.
Either none or all work items of a workgroup need to execute this op in convergence.
Implementations
Sourceimpl<'c> BarrierOperation<'c>
impl<'c> BarrierOperation<'c>