pub struct CreateCooOperation<'c> { /* private fields */ }Expand description
A create_coo operation. Create sparse matrix in COO format operation.
The gpu.create_coo operation initializes a sparse matrix in COO format
with the given sizes from the given index and values buffers. The buffers
must already be copied from the host to the device prior to using this
operation. The operation returns a handle to the sparse matrix descriptor.
Note that this operation builds the COO in SoA format.
If the async keyword is present, the op is executed asynchronously (i.e.
it does not block until the execution has finished on the device). In
that case, it returns a !gpu.async.token in addition to the environment.
Example:
%spmat, %token = gpu.create_coo async [%dep] %rows, %cols, %nnz, %rowIdx,
%colIdx, %values : memref<?xindex>, memref<?xindex>, memref<?xf64>Implementations
Sourceimpl<'c> CreateCooOperation<'c>
impl<'c> CreateCooOperation<'c>
Sourcepub fn as_operation(&self) -> &Operation<'c>
pub fn as_operation(&self) -> &Operation<'c>
Returns a generic operation.
Sourcepub fn builder(
context: &'c Context,
location: Location<'c>,
) -> CreateCooOperationBuilder<'c, Unset, Unset, Unset, Unset, Unset, Unset, Unset, Unset>
pub fn builder( context: &'c Context, location: Location<'c>, ) -> CreateCooOperationBuilder<'c, Unset, Unset, Unset, Unset, Unset, Unset, Unset, Unset>
Creates a builder.
pub fn spmat(&self) -> Result<OperationResult<'c, '_>, Error>
pub fn async_token(&self) -> Result<OperationResult<'c, '_>, Error>
pub fn async_dependencies(&self) -> impl Iterator<Item = Value<'c, '_>>
pub fn rows(&self) -> Result<Value<'c, '_>, Error>
pub fn cols(&self) -> Result<Value<'c, '_>, Error>
pub fn nnz(&self) -> Result<Value<'c, '_>, Error>
pub fn row_idxs(&self) -> Result<Value<'c, '_>, Error>
pub fn col_idxs(&self) -> Result<Value<'c, '_>, Error>
pub fn values(&self) -> Result<Value<'c, '_>, Error>