pub struct ThreadIdOperation<'c> { /* private fields */ }Expand description
A thread_id operation.
Returns the thread id, i.e. the index of the current thread within the block
along the x, y, or z dimension.
Example:
%tIdX = gpu.thread_id xIf upper_bound is set, or if one can be inferred from known_block_size-type
annotations in context, executions where the thread index would be greater
than or equal to that bound cause undefined behavior.
There is an implicit upper bound of kMaxDim (currently uint32_t::max).
Implementations
Sourceimpl<'c> ThreadIdOperation<'c>
impl<'c> ThreadIdOperation<'c>
Sourcepub fn as_operation(&self) -> &Operation<'c>
pub fn as_operation(&self) -> &Operation<'c>
Returns a generic operation.
Sourcepub fn builder(
context: &'c Context,
location: Location<'c>,
) -> ThreadIdOperationBuilder<'c, Unset>
pub fn builder( context: &'c Context, location: Location<'c>, ) -> ThreadIdOperationBuilder<'c, Unset>
Creates a builder.
pub fn dimension(&self) -> Result<Attribute<'c>, Error>
pub fn set_dimension(&mut self, value: Attribute<'c>)
pub fn upper_bound(&self) -> Result<IntegerAttribute<'c>, Error>
pub fn set_upper_bound(&mut self, value: IntegerAttribute<'c>)
pub fn remove_upper_bound(&mut self) -> Result<(), Error>